@@ -55,8 +55,8 @@ class ConvertDataBuildTarget(SingleBuildTarget):
 
     def get_config(self):
         return {
-            'from': self.from_type,
-            'to': self.to_type,
+            'from': self.from_type.value,
+            'to': self.to_type.value,
             'indent_chars': self.indent_chars,
             'pretty_print': self.pretty_print,
         }
